Pressure

Type Alias Pressure 

pub type Pressure = Qty<-1, 1, -2, 0, 0, 0, 0>;
Pascals. Also the unit of an energy density and of a stress, which are the same dimension and not a coincidence.

Aliased Type

pub struct Pressure(/* private fields */);